@@ -27,10 +27,10 @@ pub struct IndividualObj {
 #[derive(Debug)]
 pub struct RawObj {
     pub data: Vec<u8>,
-    pub cur: u64,
-    pub len_predicates: u32,
-    pub cur_predicates: u32,
-    pub raw_type: RawType,
+    pub(crate) cur: u64,
+    pub(crate) len_predicates: u32,
+    pub(crate) cur_predicates: u32,
+    pub(crate) raw_type: RawType,
 }
 
 impl RawObj {
